Slot: slot_usage - LinkML Model

# Slot: slot_usage

the redefinition of a slot in the context of the containing class definition.

URI: linkml:slot_usage

## Domain and Range

ClassDefinition → 0..* SlotDefinition

## Parents

## Children

## Used by

- ClassDefinition

## Other properties

Comments: |  | Many slots may be re-used across different classes, but the meaning of the slot may be refined by context. For example, a generic association model may use slots subject/predicate/object with generic semantics and minimal constraints. When this is subclasses, e.g. to disease-phenotype associations then slot usage may specify both local naming (e.g. subject=disease) and local constraints